"use strict";

require("core-js/modules/es.symbol");

require("core-js/modules/es.array.filter");

require("core-js/modules/es.array.for-each");

require("core-js/modules/es.object.assign");

require("core-js/modules/es.object.get-own-property-descriptor");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/es.object.keys");

require("core-js/modules/web.dom-collections.for-each");

var _react = _interopRequireDefault(require("react"));

var _reactTestRenderer = _interopRequireDefault(require("react-test-renderer"));

var _mocks = require("../../mocks");

var _styled = require("./styled");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe("Selection", function () {
  it("styles", function () {
    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Selection, _extends({}, _mocks.mockStyles, {
      item: _mocks.mockItem,
      removable: false,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("removable = true", function () {
    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Selection, _extends({}, _mocks.mockStyles, {
      item: _mocks.mockItem,
      removable: true,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("should highlight removable", function () {
    var mockHighlightedItem = _objectSpread({}, _mocks.mockItem, {
      value: "highlight"
    });

    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Selection, _extends({}, _mocks.mockStyles, {
      item: mockHighlightedItem,
      styles_selectionHighlighted: mockHighlightedItem.value,
      removable: true,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("styles_multiple = true", function () {
    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Selection, _extends({}, _mocks.mockStyles, {
      item: _mocks.mockItem,
      styles_multiple: true,
      removable: false,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("styles_rightToLeft = true", function () {
    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Selection, _extends({}, _mocks.mockStyles, {
      item: _mocks.mockItem,
      styles_rightToLeft: true,
      removable: false,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("styles_rightToLeft = true and removable = true", function () {
    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Selection, _extends({}, _mocks.mockStyles, {
      item: _mocks.mockItem,
      styles_rightToLeft: true,
      removable: true,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
});
describe("Option", function () {
  it("styles", function () {
    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Option, _extends({}, _mocks.mockStyles, {
      item: _mocks.mockItem,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("should highlight", function () {
    var mockHighlightedItem = _objectSpread({}, _mocks.mockItem, {
      value: "highlight"
    });

    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Option, _extends({}, _mocks.mockStyles, {
      item: mockHighlightedItem,
      styles_optionHighlighted: mockHighlightedItem.value,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("should not highlight if empty value", function () {
    var mockHighlightedItem = _objectSpread({}, _mocks.mockItem, {
      value: null
    });

    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Option, _extends({}, _mocks.mockStyles, {
      item: mockHighlightedItem,
      styles_optionHighlighted: mockHighlightedItem.value,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("styles_rightToLeft = true", function () {
    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Option, _extends({}, _mocks.mockStyles, {
      item: _mocks.mockItem,
      styles_rightToLeft: true,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("has item group and parent = true", function () {
    var mockGroupItem = _objectSpread({}, _mocks.mockItem, {
      group: "item group",
      parent: true
    });

    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Option, _extends({}, _mocks.mockStyles, {
      item: mockGroupItem,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("has item group and parent = true and value = null", function () {
    var mockGroupItem = _objectSpread({}, _mocks.mockItem, {
      group: "item group",
      parent: true,
      value: null
    });

    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Option, _extends({}, _mocks.mockStyles, {
      item: mockGroupItem,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
  it("has item group and parent = false", function () {
    var mockGroupItem = _objectSpread({}, _mocks.mockItem, {
      group: "item group",
      parent: false
    });

    var wrapper = _reactTestRenderer.default.create( /*#__PURE__*/_react.default.createElement(_styled.Option, _extends({}, _mocks.mockStyles, {
      item: mockGroupItem,
      svg_Remove: _mocks.MockSvg
    })));

    expect(wrapper).toMatchSnapshot();
  });
});