import massageDataIn from "./massageDataIn";

let props;
let funcValueKey = obj => obj["value"];
let funcLabelKey = obj => obj["label"];

beforeEach(() => {
  props = {
    selection: "",
    options: [],
    placeholder: "",
    valueKey: funcValueKey,
    labelKey: funcLabelKey
  };
});

it("empty values, selection should always be an array", () => {
  expect(massageDataIn(props)).toStrictEqual({
    hasOptionGroups: false,
    hasOptions: false,
    hasSelection: false,
    options: [],
    selection: [],
    singleNoOptions: undefined,
    text_placeholder: "",
    valueKey: funcValueKey,
    labelKey: funcLabelKey
  });
});

it("single Selection should always be an array of objects", () => {
  props.selection = "1";

  expect(massageDataIn(props)).toStrictEqual({
    hasOptionGroups: false,
    hasOptions: false,
    hasSelection: true,
    options: [],
    selection: [
      {
        label: "1",
        value: "1"
      }
    ],
    singleNoOptions: undefined,
    text_placeholder: "",
    valueKey: funcValueKey,
    labelKey: funcLabelKey
  });
});

it("selection should always convert to strings", () => {
  props.selection = [1, 2];

  expect(massageDataIn(props)).toStrictEqual({
    hasOptionGroups: false,
    hasOptions: false,
    hasSelection: true,
    options: [],
    selection: [
      {
        label: "1",
        value: "1"
      },
      {
        label: "2",
        value: "2"
      }
    ],
    singleNoOptions: undefined,
    text_placeholder: "",
    valueKey: funcValueKey,
    labelKey: funcLabelKey
  });
});

it("Options should always be objects of strings", () => {
  props.options = [
    {
      label: 1,
      value: 1
    }
  ];

  expect(massageDataIn(props)).toStrictEqual({
    hasOptionGroups: false,
    hasOptions: true,
    hasSelection: false,
    options: [
      {
        label: "1",
        value: "1"
      }
    ],
    selection: [],
    singleNoOptions: false,
    text_placeholder: "",
    valueKey: funcValueKey,
    labelKey: funcLabelKey
  });
});
